An R interface for generating features for a cohort using data in the Common Data Model. Features can be constructed using default or custom made feature definitions. Furthermore it's possible to aggregate features and get the summary statistics.
Maintainer: Ger Inberg [email protected]
Authors:
Martijn Schuemie [email protected]
Marc Suchard
Patrick Ryan
Jenna Reps
Anthony Sena [email protected]
Other contributors:
Observational Health Data Science and Informatics [copyright holder]
Useful links: