replaceCovariateSettingsCohortSchemaTable: Utility function to set the cohort table & schema on...

View source: R/GetCovariatesFromOtherCohorts.R

replaceCovariateSettingsCohortSchemaTableR Documentation

Utility function to set the cohort table & schema on createCohortBasedCovariateSettings with information from the execution settings

Description

Utility function to set the cohort table & schema on createCohortBasedCovariateSettings with information from the execution settings

Usage

replaceCovariateSettingsCohortSchemaTable(
  covariateSettings,
  covariateCohortDatabaseSchema,
  covariateCohortTable
)

Arguments

covariateSettings

An object of type covariateSettings

covariateCohortDatabaseSchema

The database schema where the cohorts used to define the covariates can be found.

covariateCohortTable

The table where the cohorts used to define the covariates can be found.

Value

An object of type covariateSettings


FeatureExtraction documentation built on June 26, 2026, 5:07 p.m.