View source: R/GetCovariatesFromOtherCohorts.R
| replaceCovariateSettingsCohortSchemaTable | R Documentation |
Utility function to set the cohort table & schema on createCohortBasedCovariateSettings with information from the execution settings
replaceCovariateSettingsCohortSchemaTable(
covariateSettings,
covariateCohortDatabaseSchema,
covariateCohortTable
)
covariateSettings |
An object of type |
covariateCohortDatabaseSchema |
The database schema where the cohorts used to define the covariates can be found. |
covariateCohortTable |
The table where the cohorts used to define the covariates can be found. |
An object of type covariateSettings
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.